@@ -17,11 +17,8 @@ ma_search <- function(query, count = 10, offset = 0, orderby = NULL,
 
   if (!is.null(atts)) atts <- paste0(atts, collapse = ",")
   out <- ma_evaluate(query, count, offset, orderby, atts, model, key, ...)
-  ee <- dfrbl(lapply(out$E, function(z) {
-    dat <- jsonlite::fromJSON(z)
-    dat <- dat[names(dat) %in% c('DN', 'VFN', 'DOI', 'D')]
-    data.frame(dat, stringsAsFactors = FALSE)
-  }))
   out$E <- NULL
-  tibble::as_tibble(cbind(out, ee))
+  out[grepl("IA.+", names(out))] <- NULL
+  out[grepl("CitCon.+", names(out))] <- NULL
+  return(out)
 }
