@@ -11,4 +11,10 @@ test_that("ma_abstract works as expected", {
     expect_is(aa$abstract, "character")
     expect_equal(NROW(aa), 10)
   }, preserve_exact_body_bytes = TRUE)
+
+  vcr::use_cassette("ma_abstract_no_NAs", {
+    res <- ma_abstract("Id=2142076420")
+    expect_false(grepl("\\bNA\\b", res$abstract))
+  }, preserve_exact_body_bytes = TRUE)
+
 })
